@@ -44,6 +44,27 @@ class WelfareNumber(Base):
         result.sort()
         return result
 
+    @classmethod
+    def get_issue_future(cls):
+        """get issues[list]"""
+        session = get_session_welfare()
+        i = session.query(cls).all()
+        session.close()
+        last = [x.issue for x in i]
+        last.sort()
+        result = last + 1
+        return result
+
+    @classmethod
+    def get_previous_issues_by_num(cls, issue_now, num):
+        all_issues = cls.get_issues()
+        issue_now = int(issue_now)
+        if issue_now in all_issues:
+            index_now = all_issues.index(issue_now)
+            return all_issues[index_now - num: index_now]
+        else:
+            return all_issues[-num:]
+
     @classmethod
     def get_previous3_issues(cls, issue_now):
         all_issues = cls.get_issues()
